# Docsy

A docs site generator written with Python.

## Installation

Install using Git or download manually

**Git:**
```bash
git clone https://github.com/ginoblog/docsy.git (your site path)
```

Download manually:
[Download here](https://docsy.inet2.org/download/ "Downloads")

## How to use

Use Python to run the program
```bash
cd my-site-path
python scripts/render.py
```

## Development

Still developing

## Contributors

@ginoblog
@sclass53
